# CHANGELOG

<!-- version list -->

## v1.0.1 (2026-03-25)

### Bug Fixes

- Trigger release lol
  ([`cded674`](https://github.com/nachollorca/lmti/commit/cded674f25039253e5a68fa3d5691a79e2473f44))


## v1.0.0 (2026-03-24)

- Initial Release
